@@ -11,7 +11,7 @@ use Plift::Context;
 use Digest::MD5 qw/ md5_hex /;
 use namespace::clean;
 
-our $VERSION = "0.10";
+our $VERSION = "0.11";
 
 use constant {
     XML_DOCUMENT_NODE      => 9,
@@ -50,8 +50,50 @@ sub BUILD {
     push @components, map { /^\+/ ? $_ : 'Plugin::'.$_ } @{ $self->plugins };
 
     $self->load_components(@components);
+
+    ## remove-if / remove-unless
+    $self->hook('after_load_template', \&_after_load_template);
 }
 
+sub _after_load_template {
+    my ($c, $dom) = @_;
+
+    # remove-if/unless
+    my $xpath =  join ' | ', map { ("./*[\@$_]", ".//*[\@$_]") }
+                             map { "data-$_"  }
+                             qw/ remove-if remove-unless /;
+
+    foreach my $node ( @{ $dom->xfilter($xpath)->{nodes} }, @{ $dom->xfind($xpath)->{nodes} } ) {
+
+        # remove-if
+        if (exists $node->{'remove-if'} || exists $node->{'data-remove-if'} ) {
+
+            if ($c->get($node->{'remove-if'} || $node->{'data-remove-if'})) {
+
+                $node->unbindNode;
+            } else {
+
+                delete $node->{'remove-if'};
+                delete $node->{'data-remove-if'};
+            }
+        }
+
+        # remove-unless
+        if (exists $node->{'remove-unless'} || exists $node->{'data-remove-unless'} ) {
+
+            unless ($c->get($node->{'remove-unless'} || $node->{'data-remove-unless'})) {
+
+                $node->unbindNode;
+            } else {
+
+                delete $node->{'remove-unless'};
+                delete $node->{'data-remove-unless'};
+            }
+        }
+    }
+}
+
+
 sub load_components {
     my $self = shift;
 
@@ -98,6 +140,9 @@ sub template {
         load_snippet => sub {
             $self->_load_snippet(\@ns, @_);
         },
+        run_hooks => sub {
+            $self->run_hooks(@_);
+        },
     );
 }
 
@@ -172,6 +217,28 @@ sub get_handler {
 }
 
 
+
+my %hooks;
+sub hook {
+    my ($self, $step, $cb) = @_;
+
+    croak "Usage: plift->hook(<step>, <callback>)"
+        unless $step && $cb && ref $cb eq 'CODE';
+
+    push @{$hooks{$step}}, $cb;
+    $self;
+}
+
+sub run_hooks {
+    my ($self, $step, $args) = @_;
+
+    foreach my $cb (@{ $hooks{$step} || [] }) {
+        $cb->(@{ $args || [] });
+    }
+}
+
+
+
 sub _load_template {
     my ($self, $template, $paths, $ctx) = @_;
 
@@ -309,8 +376,6 @@ sub _load_template {
         $ctx->document($dom->document);
     }
 
-    # TODO apply input filters
-
     $dom;
 }
 
